ErrorKind

Enum ErrorKind 

#[repr(u8)]
pub enum ErrorKind {
Show 14 variants Other = 0, MaxFrameSizeExceeded = 1, InvalidHeader = 2, SegmentViolation = 3, BadVarInt = 4, InvalidChannel = 5, InProgress = 6, ResponseTooLarge = 7, RequestTooLarge = 8, DuplicateRequest = 9, FictitiousRequest = 10, RequestLimitExceeded = 11, FictitiousCancel = 12, CancellationLimitExceeded = 13,
}
Error kind, from the kind byte.

Variants



Other = 0

Application defined error.



MaxFrameSizeExceeded = 1

The maximum frame size has been exceeded. This error cannot occur in this implementation, which operates solely on streams.



InvalidHeader = 2

An invalid header was received.



SegmentViolation = 3

A segment was sent with a frame where none was allowed, or a segment was too small or missing.



BadVarInt = 4

A varint32 could not be decoded.



InvalidChannel = 5

Invalid channel: A channel number greater than the highest channel number was received.



InProgress = 6

A new request or response was sent without completing the previous one.



ResponseTooLarge = 7

The indicated size of the response would exceed the configured limit.



RequestTooLarge = 8

The indicated size of the request would exceed the configured limit.



DuplicateRequest = 9

Peer attempted to create two in-flight requests with the same ID on the same channel.



FictitiousRequest = 10

Sent a response for request not in-flight.



RequestLimitExceeded = 11

The dynamic request limit has been exceeded.



FictitiousCancel = 12

Response cancellation for a request not in-flight.



CancellationLimitExceeded = 13

Peer sent a request cancellation exceeding the cancellation allowance.

Implementations

Source

impl ErrorKind

pub const fn from_repr(discriminant: u8) -> Option<ErrorKind>

Try to create Self from the raw representation