pub enum EnqueueError {
Closed(Option<Bytes>),
BufferLimitHit(Option<Bytes>),
}Expand description
An error that can occur while attempting to enqueue an item.
Variants
Closed(Option<Bytes>)
The IO core was shut down, there is no connection anymore to send through.
BufferLimitHit(Option<Bytes>)
The request limit for locally buffered requests was hit, try again.