pub struct FrameIter { /* private fields */ }Expand description
Iterator over frames of a message.
Implementations
Sourceimpl FrameIter
impl FrameIter
Sourcepub fn next_owned(
self,
max_frame_size: MaxFrameSize,
) -> (OutgoingFrame, Option<Self>)
pub fn next_owned( self, max_frame_size: MaxFrameSize, ) -> (OutgoingFrame, Option<Self>)
Returns the next frame to send.
Will return the next frame, and Some(self) if there are additional frames to send to
complete the message, None otherwise.
Note
While different OutgoingMessages can have their send order mixed or interspersed, a
caller MUST NOT send OutgoingFrames of a single message in any order but the one
produced by this method. In other words, reorder messages, but not frames within a message.